/* Copyright (C) 2008 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _WIDGET_H_
#define _WIDGET_H_

#include "node.h"

@interface Widget: Node {
    GLfloat color[4];
    float requested[2], allocated[2], minimum[2];
    GLfloat padding[2];
    int align[2];
}

-(GLfloat *)color;
-(float) opacity;
-(float) width;
-(float) height;

@end

#endif
